@@ -1254,14 +1254,17 @@ class EntryBlock(collections.namedtuple('EntryBlock', 'type size repCode value')
             r.extend(RepCode.writeBytes(self.value, self.repCode))
         return r
 
-class EntryBlockRead(EntryBlock):
-    """An entry block read from a LIS file."""
-    def __new__(self, theFile):
-        t, s, r = theFile.unpack(STRUCT_ENTRY_BLOCK_PREAMBLE)
-        if s == 0:
-            # Special case when size is 0
-            return super(EntryBlockRead, self).__new__(self, t, s, r, None)
-        return super(EntryBlockRead, self).__new__(self, t, s, r, RepCode.readRepCode(r, theFile, s))
+
+def create_entry_block(theFile):
+    t, s, r = theFile.unpack(STRUCT_ENTRY_BLOCK_PREAMBLE)
+    if s == 0:
+        # Special case when size is 0
+        rep_code = None
+    else:
+        rep_code = RepCode.readRepCode(r, theFile, s)
+    eb = EntryBlock(t, s, r, rep_code)
+    return eb
+
 
 class EntryBlockSet(object):
     """Represents the set of Entry Blocks in a DFSR."""
@@ -1350,10 +1353,9 @@ class EntryBlockSet(object):
     
     def __getattr__(self, name):
         """Returns the Entry Block corresponding to the name."""
-        try:
+        if name in self.ATTR_MAP:
             return self._ebS[self.ATTR_MAP[name]].value
-        except KeyError or IndexError as err:
-            raise AttributeError(str(err))
+        raise AttributeError(f'{name} not in self._ATTR_MAP')
     
     def __getitem__(self, key):
         """This returns an Entry block by integer index."""
@@ -1436,7 +1438,7 @@ class EntryBlockSet(object):
         """Reads from a File object. NOTE: theFile.hasLd() must be True so
         the Logical Record Header must have been read already."""
         while theFile.hasLd():
-            eb = EntryBlockRead(theFile)
+            eb = create_entry_block(theFile)
             try:
                 self.setEntryBlock(eb)
             except ExceptionEntryBlock as err:
